from PIL import Image
from tw2.core import Validator, ValidationError
from tw2.forms import FileValidator
from tg.i18n import lazy_ugettext as l_
import re

class PhoneNumberValidator(Validator):
    strip = True
    regex = re.compile(r'^\+[\d\s]+$')

    def _convert_to_python(self, value, state=None):
        value = super(PhoneNumberValidator, self)._convert_to_python(value)
        if value.startswith('00'):
            value = '+' + value[2:]
        return value

    def _validate_python(self, value, state=None):
        if not self.regex.match(value):
            raise ValidationError(l_('Not a valid internatinal phone number'), self)

class RangeDateValidator(Validator):
    def __init__(self, from_date, to_date, **kw):
        super(RangeDateValidator, self).__init__(**kw)
        self.from_date = from_date
        self.to_date = to_date

    def _validate_python(self, values, state=None):
        if values.get(self.from_date) > values.get(self.to_date):
            raise ValidationError(l_('Starting date must be previous than ending date'), self)


class ImageValidator(FileValidator):

    format = ()
    size = ()
    def __init__(self, **kw):
        super(ImageValidator, self).__init__(**kw)


    def _validate_python(self, image, state=None):
        try:
            img = Image.open(image.file)
            image.file.seek(0)
        except:
            raise ValidationError(l_('Invalid Image'), self)
        if self.format and img.format.lower() not in self.format:
            raise ValidationError(l_('Image format is invalid, must be %s' % (self.format,)), self)
        if self.size and img.size != self.size:
            raise ValidationError(l_('Image size must be %s * %s' % (self.size[0], self.size[1])), self)



from axf.axel import AxelWidgetMixin, AxelScript
from tw2 import forms
from tw2.core import Param

class AjaxCascadingField(forms.InputField, AxelWidgetMixin):
    axel_styles = []
    datasource = Param('Url that will be called to retrieve the data', request_local=False)
    onevent = Param('A tuple (id, event[currently ignored]) that specifies which event of which element' +
                    'triggers options to be reloaded from the datasource', request_local=False)
    axel_scripts = [AxelScript('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js',
                               load=False),
                    AxelScript('AjaxCascadingField', 'scripts.js', load=False,
                               callback='AjaxCascadingField_init'),
                    AxelScript(['jquery', 'AjaxCascadingField'], load=True)]

    def prepare(self):
        if self.type == 'textarea':
            self.safe_modify('template')
            self.template = "tw2.forms.templates.textarea"
        super(AjaxCascadingField, self).prepare()
        self.axel_prepare(self.onevent[0], self.onevent[1], self.datasource, self.value)


from tw2.core import Widget, Param, JSSource
from tg import json_encode


class UIDJSSource(JSSource):
    def __eq__(self, other):
        return self.id == other.id


class RactiveGlobalJSSource(UIDJSSource):
    id = 'RactiveWidgets'
    location = 'head'
    src = '''
document.RAWidgets = {};
document.RAWidgets.display = function(id, WidgetClass, data) {
    var placeholder = document.getElementById(id);
    var parentNode = placeholder.parentNode;
    var widget = document.RAWidgets[id] = new WidgetClass({el: parentNode, append: true, data: data});
    parentNode.insertBefore(parentNode.lastChild, placeholder);
    parentNode.removeChild(placeholder);
};
'''


class RactiveTemplateSource(UIDJSSource):
    inline_engine_name = 'genshi'
    template = '''
<script id="${w.id}" type="text/ractive">
    ${w.src}
</script>'''


class RactiveClassSource(UIDJSSource):
    template_id = Param('Ractive template dom id')
    ractive_base = Param('Ractive Base Widget Class', default='Ractive')

    inline_engine_name = 'genshi'
    template = '''
<script>
    var ${w.id} = ${w.ractive_base}.extend({
        template: "#${w.template_id}",
        init: $w.src
    });
</script>
'''


class RactiveWidget(Widget):
    template = '<div xmlns:py="http://genshi.edgewall.org/" py:attrs="w.attrs"/>'
    inline_engine_name = 'genshi'

    ractive_template = Param('The template of the Ractive Widget')
    ractive_init = Param('Ractive initialization function', default='function(options){ if (this._super !== undefined) this._super(options); }')
    ractive_base = Param('Name of the base Ractive class', default='Ractive')
    ractive_class = Param('Name of the Ractive Widget', default=None)
    ractive_params = Param('List of widget params that need to be passed to Ractive', default=[])

    @classmethod
    def post_define(cls):
        if not hasattr(cls, 'ractive_template'):
            return

        if cls.ractive_class is None:
            cls.ractive_class = cls.__name__

        template_id = '_'.join(('rt_template', cls.ractive_class))

        cls.resources.append(RactiveGlobalJSSource())
        cls.resources.append(RactiveTemplateSource(id=template_id,
                                                   src=cls.ractive_template))
        cls.resources.append(RactiveClassSource(id=cls.ractive_class,
                                                ractive_base=cls.ractive_base,
                                                template_id=template_id,
                                                src=cls.ractive_init))

    @classmethod
    def activate(cls):
        resources = [r.req() for r in cls.resources]
        for r in resources:
            r.prepare()

    def prepare(self):
        super(RactiveWidget, self).prepare()
        self.safe_modify('attrs')
        self.attrs['id'] = self.id

        if self.value is None:
            self.value = {}

        ractive_params = dict([(prop, getattr(self, prop)) for prop in self.ractive_params])

        try:
            self.value = self.value.copy()
        except:
            # Value must be a dictionary and so support copy
            self.value = {}

        self.value.update(ractive_params)

        self.safe_modify('resources')
        self.resources.append(JSSource(src='''
document.RAWidgets.display("%(id)s", %(RactiveClass)s, %(value)s);
''' % dict(id=self.id, RactiveClass=self.ractive_class,
           value=json_encode(self.value))))






from tw2 import forms
from tw2.core import Param, Link
from axf.axel import AxelWidgetMixin, AxelScript, AxelStyle

class WysiHtml5TextArea(forms.TextArea, AxelWidgetMixin):
    template = "axf.widgets.wysihtml5_text_area.wysihtml5_text_area"
    axel_styles = [AxelStyle('wysihtml5_text_area', 'resources/wysihtml5_text_area.css')]

    axel_scripts = [AxelScript('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js',
                               load=False),
                    AxelScript('wysihtml5', 'resources/wysihtml5-0.3.0.min.js', load=False),
                    AxelScript('wysihtml5ParserRules', 'resources/parser_rules/advanced.js', load=False),
                    AxelScript('WysiHtml5TextArea', 'scripts.js', load=False,
                               callback='WysiHtml5TextArea_init'),
                    AxelScript(['jquery', 'wysihtml5', 'wysihtml5ParserRules', 'WysiHtml5TextArea'], load=True)]

    def prepare(self):
        super(WysiHtml5TextArea, self).prepare()
        self.axel_prepare()


"""
PHP date() style date formatting
See http://www.php.net/date for format strings

Usage:
>>> import datetime
>>> d = datetime.datetime.now()
>>> df = DateFormat(d)
>>> print(df.format('jS F Y H:i'))
7th October 2003 11:39
>>>
"""
from __future__ import unicode_literals

import re
import time
import calendar

from tg.i18n import lazy_ugettext as _
from tg._compat import unicode_text

WEEKDAYS = {
    0:_('Monday'), 1:_('Tuesday'), 2:_('Wednesday'), 3:_('Thursday'), 4:_('Friday'),
    5:_('Saturday'), 6:_('Sunday')
}
WEEKDAYS_ABBR = {
    0:_('Mon'), 1:_('Tue'), 2:_('Wed'), 3:_('Thu'), 4:_('Fri'),
    5:_('Sat'), 6:_('Sun')
}
WEEKDAYS_REV = {
    'monday':0, 'tuesday':1, 'wednesday':2, 'thursday':3, 'friday':4,
    'saturday':5, 'sunday':6
}
MONTHS = {
    1:_('January'), 2:_('February'), 3:_('March'), 4:_('April'), 5:_('May'), 6:_('June'),
    7:_('July'), 8:_('August'), 9:_('September'), 10:_('October'), 11:_('November'),
    12:_('December')
}
MONTHS_3 = {
    1:_('jan'), 2:_('feb'), 3:_('mar'), 4:_('apr'), 5:_('may'), 6:_('jun'),
    7:_('jul'), 8:_('aug'), 9:_('sep'), 10:_('oct'), 11:_('nov'), 12:_('dec')
}
MONTHS_3_REV = {
    'jan':1, 'feb':2, 'mar':3, 'apr':4, 'may':5, 'jun':6, 'jul':7, 'aug':8,
    'sep':9, 'oct':10, 'nov':11, 'dec':12
}

re_formatchars = re.compile(r'(?<!\\)([aAbBcdDeEfFgGhHiIjlLmMnNoOPrsStTUuwWyYzZ])')
re_escaped = re.compile(r'\\(.)')


class Formatter(object):
    def format(self, formatstr):
        pieces = []
        for i, piece in enumerate(re_formatchars.split(unicode_text(formatstr))):
            if i % 2:
                pieces.append(unicode_text(getattr(self, piece)()))
            elif piece:
                pieces.append(re_escaped.sub(r'\1', piece))
        return ''.join(pieces)


class TimeFormat(Formatter):
    def __init__(self, t):
        self.data = t

    def a(self):
        "'a.m.' or 'p.m.'"
        if self.data.hour > 11:
            return _('p.m.')
        return _('a.m.')

    def A(self):
        "'AM' or 'PM'"
        if self.data.hour > 11:
            return _('PM')
        return _('AM')

    def B(self):
        "Swatch Internet time"
        raise NotImplementedError

    def f(self):
        """
        Time, in 12-hour hours and minutes, with minutes left off if they're
        zero.
        Examples: '1', '1:30', '2:05', '2'
        Proprietary extension.
        """
        if self.data.minute == 0:
            return self.g()
        return '%s:%s' % (self.g(), self.i())

    def g(self):
        "Hour, 12-hour format without leading zeros; i.e. '1' to '12'"
        if self.data.hour == 0:
            return 12
        if self.data.hour > 12:
            return self.data.hour - 12
        return self.data.hour

    def G(self):
        "Hour, 24-hour format without leading zeros; i.e. '0' to '23'"
        return self.data.hour

    def h(self):
        "Hour, 12-hour format; i.e. '01' to '12'"
        return '%02d' % self.g()

    def H(self):
        "Hour, 24-hour format; i.e. '00' to '23'"
        return '%02d' % self.G()

    def i(self):
        "Minutes; i.e. '00' to '59'"
        return '%02d' % self.data.minute

    def P(self):
        """
        Time, in 12-hour hours, minutes and 'a.m.'/'p.m.', with minutes left off
        if they're zero and the strings 'midnight' and 'noon' if appropriate.
        Examples: '1 a.m.', '1:30 p.m.', 'midnight', 'noon', '12:30 p.m.'
        Proprietary extension.
        """
        if self.data.minute == 0 and self.data.hour == 0:
            return _('midnight')
        if self.data.minute == 0 and self.data.hour == 12:
            return _('noon')
        return '%s %s' % (self.f(), self.a())

    def s(self):
        "Seconds; i.e. '00' to '59'"
        return '%02d' % self.data.second

    def u(self):
        "Microseconds; i.e. '000000' to '999999'"
        return '%06d' %self.data.microsecond


class DateFormat(TimeFormat):
    year_days = [None, 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334]

    def __init__(self, dt):
        # Accepts either a datetime or date object.
        self.data = dt

    def b(self):
        "Month, textual, 3 letters, lowercase; e.g. 'jan'"
        return MONTHS_3[self.data.month]

    def B(self):
        "Month, textual, 3 letters, capitalized"
        return unicode_text(self.b()).capitalize()

    def c(self):
        """
        ISO 8601 Format
        Example : '2008-01-02T10:30:00.000123'
        """
        return self.data.isoformat()

    def d(self):
        "Day of the month, 2 digits with leading zeros; i.e. '01' to '31'"
        return '%02d' % self.data.day

    def D(self):
        "Day of the week, textual, 3 letters; e.g. 'Fri'"
        return WEEKDAYS_ABBR[self.data.weekday()]

    def e(self):
        "Timezone name if available"
        try:
            if hasattr(self.data, 'tzinfo') and self.data.tzinfo:
                # Have to use tzinfo.tzname and not datetime.tzname
                # because datatime.tzname does not expect Unicode
                return self.data.tzinfo.tzname(self.data) or ""
        except NotImplementedError:
            pass
        return ""

    def F(self):
        "Month, textual, long; e.g. 'January'"
        return MONTHS[self.data.month]

    def j(self):
        "Day of the month without leading zeros; i.e. '1' to '31'"
        return self.data.day

    def l(self):
        "Day of the week, textual, long; e.g. 'Friday'"
        return WEEKDAYS[self.data.weekday()]

    def L(self):
        "Boolean for whether it is a leap year; i.e. True or False"
        return calendar.isleap(self.data.year)

    def m(self):
        "Month; i.e. '01' to '12'"
        return '%02d' % self.data.month

    def M(self):
        "Month, textual, 3 letters; e.g. 'Jan'"
        return MONTHS_3[self.data.month].title()

    def n(self):
        "Month without leading zeros; i.e. '1' to '12'"
        return self.data.month

    def o(self):
        "ISO 8601 year number matching the ISO week number (W)"
        return self.data.isocalendar()[0]

    def O(self):
        "Difference to Greenwich time in hours; e.g. '+0200', '-0430'"
        seconds = self.Z()
        sign = '-' if seconds < 0 else '+'
        seconds = abs(seconds)
        return "%s%02d%02d" % (sign, seconds // 3600, (seconds // 60) % 60)

    def r(self):
        "RFC 2822 formatted date; e.g. 'Thu, 21 Dec 2000 16:01:07 +0200'"
        return self.format('D, j M Y H:i:s O')

    def S(self):
        "English ordinal suffix for the day of the month, 2 characters; i.e. 'st', 'nd', 'rd' or 'th'"
        if self.data.day in (11, 12, 13): # Special case
            return 'th'
        last = self.data.day % 10
        if last == 1:
            return 'st'
        if last == 2:
            return 'nd'
        if last == 3:
            return 'rd'
        return 'th'

    def t(self):
        "Number of days in the given month; i.e. '28' to '31'"
        return '%02d' % calendar.monthrange(self.data.year, self.data.month)[1]

    def U(self):
        "Seconds since the Unix epoch (January 1 1970 00:00:00 GMT)"
        return int(time.mktime(self.data.timetuple()))

    def w(self):
        "Day of the week, numeric, i.e. '0' (Sunday) to '6' (Saturday)"
        return (self.data.weekday() + 1) % 7

    def W(self):
        "ISO-8601 week number of year, weeks starting on Monday"
        # Algorithm from http://www.personal.ecu.edu/mccartyr/ISOwdALG.txt
        week_number = None
        jan1_weekday = self.data.replace(month=1, day=1).weekday() + 1
        weekday = self.data.weekday() + 1
        day_of_year = self.z()
        if day_of_year <= (8 - jan1_weekday) and jan1_weekday > 4:
            if jan1_weekday == 5 or (jan1_weekday == 6 and calendar.isleap(self.data.year-1)):
                week_number = 53
            else:
                week_number = 52
        else:
            if calendar.isleap(self.data.year):
                i = 366
            else:
                i = 365
            if (i - day_of_year) < (4 - weekday):
                week_number = 1
            else:
                j = day_of_year + (7 - weekday) + (jan1_weekday - 1)
                week_number = j // 7
                if jan1_weekday > 4:
                    week_number -= 1
        return week_number

    def y(self):
        "Year, 2 digits; e.g. '99'"
        return unicode_text(self.data.year)[2:]

    def Y(self):
        "Year, 4 digits; e.g. '1999'"
        return self.data.year

    def z(self):
        "Day of the year; i.e. '0' to '365'"
        doy = self.year_days[self.data.month] + self.data.day
        if self.L() and self.data.month > 2:
            doy += 1
        return doy

def format(value, format_string):
    "Convenience function"
    df = DateFormat(value)
    return df.format(format_string)

def time_format(value, format_string):
    "Convenience function"
    tf = TimeFormat(value)
    return tf.format(format_string)


from tw2.forms import SingleSelectField
from tw2.core import Deferred, CompoundWidget
from tw2.core import validation as vd
from tw2.forms import ListLayout
from datetime import datetime
from axf.dateformat import MONTHS

class DateMonthlySelectionField(ListLayout):
    month = SingleSelectField(label=None, prompt_text=None, validator=vd.Validator(required=True),
                              options=[(idx, MONTHS[idx]) for idx in range(1, 13)])
    year = SingleSelectField(label=None, prompt_text=None, validator=vd.Validator(required=True),
                             options=Deferred(lambda: range(1950, datetime.utcnow().year+1)))

    def prepare(self):
        super(CompoundWidget, self).prepare()

        if self.value:
            if not isinstance(self.value, dict):
                self.value = self.value.strip()
                self.value = datetime.strptime(self.value, '%Y-%m-%d')
                self.value = {'month': self.value.month,
                              'year': self.value.year}
        else:
            self.value = {}

        for c in self.children:
            if c.key in self.value:
                c.value = self.value[c.key]

        for c in self.children:
            c.prepare()

    @vd.catch_errors
    def _validate(self, value, state=None):
        self._validated = True
        value = value or {}
        if not isinstance(value, dict):
            raise vd.ValidationError('corrupt', self.validator, self)

        self.value = value
        any_errors = False
        data = {}
        for c in self.children:
            try:
                data[c.key] = c._validate(value[c.key], data)
            except vd.catch:
                data[c.key] = vd.Invalid
                any_errors = True

        data = '%(year)s-%(month)s-01' % data
        if self.validator:
            data = self.validator.to_python(data, state)

        if any_errors:
            raise vd.ValidationError('childerror', self.validator, self)

        return data



import tw2.core as twc
from tw2.forms.widgets import BaseLayout, Form


class HorizontalLayout(BaseLayout):
    __doc__ = """
    Arrange widgets and labels in bootstrap3 horizontal- layout.
    """ + BaseLayout.__doc__

    template = "axf.widgets.bootstrap3.templates.horizontal_layout"


class HorizontalForm(Form):
    """Equivalent to a Form containing a HorizontalLayout."""
    child = twc.Variable(default=HorizontalLayout)
    children = twc.Required

    labels_css_class = twc.Param(
        'label css class',
        default='col-lg-2'
    )

    input_wrappers_class = twc.Param(
        'input wrapper css class',
        default='col-lg-10'
    )

    display_errors = twc.Param(
        'display error messages in help block',
        default=True
    )

    css_class = 'form-horizontal'



import inspect
from tw2.core import core
from tw2.core import middleware
from tw2.core import js_function, Param, js_callback, Link, Widget

class Axel(object):
    load = js_function('axel.load')
    register = js_function('axel.register')
    ready = js_function('axel.ready')


class _ScriptLink(Link):
    no_inject = True

    @classmethod
    def guess_modname(cls):
        try:
            frame, i = inspect.stack()[0][0], 0
            while frame.f_globals['__name__'].startswith('axf.axel') or \
                    frame.f_globals['__name__'].startswith('tw2.core'):
                frame, i = inspect.stack()[i][0], i + 1

            return frame.f_globals['__name__']
        except Exception:
            return None

    @classmethod
    def post_define(cls):
        if getattr(cls, 'filename', None):
            if not cls.modname:
                cls.modname = cls.guess_modname()
            middleware.register_resource(cls.modname or '__anon__', cls.filename, cls.whole_dir)

    def prepare(self):
        if not hasattr(self, 'link'):
            rl = core.request_local()
            resources = rl['middleware'].resources
            self.link = resources.resource_path(self.modname or '__anon__', self.filename)


class AxelScript(object):
    def __init__(self, name, link=None, callback=None, load=False):
        self.name = name
        self.link = link
        self.callback = callback
        self.load = load

    def add_calls(self, widget):
        if self.link is not None:
            if not self.link.startswith('http') and not self.link.startswith('//'):
                link = _ScriptLink(filename=self.link).req()
            else:
                link = _ScriptLink(link=self.link).req()

            link.prepare()
            widget.add_call(Axel.register(self.name, link.link))

        if self.callback is not None:
            func = js_function(self.callback)
            func_args = ['#%s' % widget.compound_id.replace(':', '\\:')]
            if hasattr(widget, '_axel_callback_args'):
                func_args.extend(widget._axel_callback_args)
            widget.add_call(Axel.ready(self.name, js_callback(func(*func_args))))

        if self.load:
            widget.add_call(Axel.load(self.name))


class AxelStyle(AxelScript):
    def __init__(self, name, link=None):
        super(AxelStyle, self).__init__(name, link)

    def add_calls(self, widget):
        if self.link is not None:
            if not self.link.startswith('http') and not self.link.startswith('//'):
                link = _ScriptLink(filename=self.link).req()
            else:
                link = _ScriptLink(link=self.link).req()

            link.prepare()
            widget.add_call(Axel.register(self.name, link.link))

        widget.add_call(Axel.load(self.name))


class AxelWidgetMixin(object):
    axel_scripts = Param('Scripts to load with the widget', request_local=False)
    axel_styles = Param('Stylesheets to load with the widget', request_local=False)

    def axel_prepare(self, *args):
        self._axel_callback_args = args

        self.safe_modify('resources')
        for script in self.axel_scripts:
            script.add_calls(self)

        for style in self.axel_styles:
            style.add_calls(self)



from axf.ractive import RactiveWidget
from tw2.core import Param, JSLink

class AjaxManagePhotos(RactiveWidget):
    action = Param('Url used to save newly uploaded photos', request_local=False)
    delete_action = Param('Url used to delete uploaded photos', request_local=False)
    permit_upload = Param('Whenever to enable upoad of new photos or only replace existing', request_local=False,
                          default=True)
    resources = [JSLink(modname=__name__, filename='resources/formdata.js')]
    ractive_params = ['action', 'delete_action', 'permit_upload', 'css_class', 'id']

    ractive_template = '''
<div id="{{id}}" class="{{css_class ? css_class : ''}}">
    {{#photos}}
    <div class="photo" intro="fade">
        {{#delete_action}}
        <div class="photo-delete" on-tap="request_delete">&#10799;</div>
        {{/delete_action}}
        <div class="photo-picture" data-photo-uid="{{uid}}" on-tap="request_upload">
            <img src="{{url}}"/>
        </div>
        {{#loading}}
            <div class='loading-photo-div'></div>
        {{/loading}}
    </div>
    {{/photos}}
    {{#permit_upload}}
    <div class="photo photo-upload" on-tap="request_upload"></div>
    {{/permit_upload}}
</div>
'''

    ractive_init = '''
function(options) {
    if (this._super !== undefined) this._super(options);

    this.on({
      request_delete: function(click_evt) {
        var self = this;

        var xhr = new XMLHttpRequest();
        xhr.open('DELETE', makeURLWithParameter(self.get('delete_action'), "uid", click_evt.context.uid), true);
        xhr.setRequestHeader("Cache-Control", "no-cache");
        xhr.setRequestHeader("X-Requested-With", "XMLHttpRequest");

        xhr.onload = function() {
            var result = JSON.parse(this.responseText);
            self.set('photos', result.photos);
        }

        xhr.send();
      },
      request_upload: function(click_evt) {

        var self = this;
        var filefield = document.createElement('input');
        filefield.type = "file";
        filefield.name = "picture";
        filefield.style = "display: none;"
        filefield.onchange = function() {
            var data = new FormData();
            data.append('file', filefield.files[0]);

            if (click_evt.context.uid)
                data.append('uid', click_evt.context.uid);

            var xhr = new XMLHttpRequest();
            xhr.open('POST', self.get('action'), true);
            xhr.setRequestHeader("Cache-Control", "no-cache");
            xhr.setRequestHeader("X-Requested-With", "XMLHttpRequest");

            xhr.onload = function() {
                var result = JSON.parse(this.responseText);
                self.set('photos', result.photos);
                self.set('loading', false);
            }

            self.set('loading', true);

            if (data.fake) {
               xhr.setRequestHeader("Content-Type", "multipart/form-data; boundary="+ data.boundary);
               xhr.sendAsBinary(data.toString());
            } else {
               xhr.send(data);
            }
        };

        window.document.body.appendChild(filefield);
        filefield.click();
        window.document.body.removeChild(filefield);
      }
    });
}'''





from setuptools import setup, find_packages
import sys, os

here = os.path.abspath(os.path.dirname(__file__))
try:
    README = open(os.path.join(here, 'README.rst')).read()
except IOError:
    README = ''

version = "0.0.12"

setup(name='axf',
      version=version,
      description="AXANT ToscaWidget2 Widgets collection",
      long_description=README,
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='',
      author='Alessandro Molina',
      author_email='alessandro.molina@axant.it',
      url='',
      license='',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'tw2.forms',
          'pillow'
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



from tw2 import forms
from tw2.core import Param


class AvatarFileField(forms.FileField):
    template = 'axf.widgets.file_field.templates.avatar_file_field'
    avatar = Param('Url of the avatar image', default='http://placehold.it/128x128')
    avatar_attrs = Param('Extra attributes to include in the img tag.', default={})



from tw2.forms import SingleSelectField
from axf.axel import AxelWidgetMixin, AxelScript

class SingleSelectFieldWithAdd(SingleSelectField, AxelWidgetMixin):
    template = "axf.widgets.single_select_with_add.single_select_with_add"

    axel_styles = []
    axel_scripts = [AxelScript('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js',
                               load=False),
                    AxelScript('SingleSelectFieldWithAdd', 'scripts.js', load=False),
                    AxelScript(['jquery', 'SingleSelectFieldWithAdd'], load=True)]

    def prepare(self):
        super(SingleSelectFieldWithAdd, self).prepare()
        self.axel_prepare()



from tw2 import forms
from tw2.core import Param, Link
from axf.axel import AxelWidgetMixin, AxelScript, AxelStyle


class AjaxAutocompleteField(forms.InputField, AxelWidgetMixin):
    type = 'hidden'
    resources = [Link(filename='/resources/select2.png'),
                 Link(filename='/resources/spinner.gif'),
                 Link(filename='/resources/select2x2.png'),
                 Link(filename='/resources/new_arrow.png')]
    axel_styles = [AxelStyle('select2-style', '/resources/select2.css')]
    axel_scripts = [AxelScript('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js',
                               load=False),
                    AxelScript('select2', 'resources/select2.min.js', load=False),
                    AxelScript('AjaxAutocompleteField', 'scripts.js', load=False,
                               callback='AjaxAutocompleteField_init'),
                    AxelScript(['jquery', 'select2', 'AjaxAutocompleteField'], load=True)]

    multiple = Param('Multiple selection enabled', request_local=False, default=False)
    datasource = Param('Url that will be called to retrieve the data', request_local=False)
    inverse_datasource = Param('Url that will be called to resolve selected entry', request_local=False)
    placeholder = Param('Placeholder to show when no selection is available',
                        default="Search for a city", request_local=False)

    def prepare(self):
        super(AjaxAutocompleteField, self).prepare()
        options = {'multiple':self.multiple}
        self.axel_prepare(str(self.placeholder), self.datasource, self.inverse_datasource, options)
